---
title: <span class="badge builder"></span> ElasticsearchMovingFunctionSettings
---
# <span class="badge builder"></span> ElasticsearchMovingFunctionSettings

## Constructor

```python
ElasticsearchMovingFunctionSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchMovingFunctionSettings
```

### <span class="badge object-method"></span> script

```python
def script(script: cogbuilder.Builder[elasticsearch.InlineScript]) -> typing.Self
```

### <span class="badge object-method"></span> shift

```python
def shift(shift: str) -> typing.Self
```

### <span class="badge object-method"></span> window

```python
def window(window: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchMovingFunctionSettings](./object-ElasticsearchMovingFunctionSettings.md)
